==> sale-1.5.88-09.jar: revenue/sqls/view/V_user_table.sql <==
{ entity.findDialect () == $SqlServer$ : $$,
 $ (
	$ } SELECT
	  t.f_userinfo_code,  --真正显示的用户编号
		t.f_user_state,
		t.f_balance,
		t.f_cost_type,
		t.f_user_name,
		t.f_address,
		t.f_address_str,
		t.f_street,
		t.f_residential_area,
		t.f_unit,
		t.f_building,
		t.f_floor,
		t.f_room,
		t.f_credentials,
		t.f_idnumber,
		t.f_user_phone,
		t.userinfo_version,
		t.f_createfile_date,
		t.f_area,
		t.f_user_id,
		t.f_userinfo_id,
		t.f_position,
		t.f_meter_base,
		t.f_total_fee,
		t.f_meternumber,
		t.f_card_id,
		t.f_aroundmeter,
		t.f_times,
		t.f_balance_amount,
	  t.f_balance_gas,
		t.f_whether_hairpin,
		t.f_gasbrand_id,
		t.f_gasmodel_id,
		t.f_price_id,
		s.id f_stairprice_id,
		s.f_price_name,
		s.f_price_type,
		t.f_inputtor,
		t.f_remanent_gas,
		t.f_table_state,
		t.version,
		t.f_input_date,
		t.f_card_password,
		t.f_metertitles,
		t.f_meter_classify,
		t.f_initial_base,
		t.f_meterid,
		t.f_open_id,
		t.f_operator,
		t.f_user_type,
		t.f_gasproperties,
		t.f_outlets,
		t.f_filiale,
		t.f_orgstr,
		t.f_filialeids,
		t.f_valve_state,
		t.f_install_person,
		t.f_install_date,
		t.f_gas_date,
		t.f_contract_id,
		t.f_taxpayer_id,
		t.f_address_phone,
		t.f_paper_name,
		t.f_paper_type,
		t.f_paper_account,
		t.f_changetube_date,
		t.f_changetube_person,
		t.f_gas_person,
		t.f_fire_state,
		t_gasbrand.id,
		t_gasbrand.f_meter_brand,
		t_gasbrand.f_manufacturers,
		t_gasbrand.f_meter_type,
		t_gasbrand.f_meter_limit,
		t_gasbrand.f_police_gas,
		t_gasbrand.f_topup_ceil,
		t_gasbrand.f_overdr_lines,
		t_gasbrand.f_alias,
		t_gasbrand.f_checkout_limit,
		t_gasbrand.f_isdecimal,
		t_gasbrand.f_collection_type,
		t_gasmodel.f_meter_style,
		t_gasmodel.f_size_card,
		t_gasmodel.f_type,
		t_gasmodel.f_rated_traffic,
		t_gasmodel.f_coding,
		t_gasmodel.f_pulse,
		t.f_comments,
		t.f_totalsplit_type,
		t.f_share_ratio,
		t.f_meter_id
	FROM
		(
			SELECT
			  t_userinfo.f_userinfo_code, --真正显示的用户编号
				t_userinfo.f_user_state,
				t_userinfo.f_balance,
				t_userinfo.f_cost_type,
				t_userinfo.f_user_name,
				t_userinfo.f_address,
				t_userinfo.f_address_str,
				t_userinfo.f_street,
				t_userinfo.f_residential_area,
				t_userinfo.f_unit,
				t_userinfo.f_building,
				t_userinfo.f_floor,
				t_userinfo.f_room,
				t_userinfo.f_credentials,
				t_userinfo.f_idnumber,
				t_userinfo.f_user_phone,
				t_userinfo.version AS userinfo_version,
				t_userinfo.f_createfile_date,
				t_userinfo.f_area,
        t_userinfo.f_open_id,
				t_userinfo.f_operator,
				t_userinfo.f_user_type,
				t_userinfo.f_gasproperties,
				t_userinfo.f_price_id,
				t_userinfo.f_contract_id,
				t_userinfo.f_taxpayer_id,
				t_userinfo.f_address_phone,
				t_userinfo.f_paper_name,
				t_userinfo.f_paper_type,
				t_userinfo.f_paper_account,
        t_userinfo.f_comments,
				t_userfiles.f_user_id,
			  t_userfiles.f_userinfo_id,
				t_userfiles.f_position,
				t_userfiles.f_meter_base,
				t_userfiles.f_total_fee,
				t_userfiles.f_meternumber,
				t_userfiles.f_card_id,
				t_userfiles.f_aroundmeter,
				t_userfiles.f_times,
				t_userfiles.f_balance_amount,
				t_userfiles.f_balance_gas,
				t_userfiles.f_whether_hairpin,
				t_userfiles.f_gasbrand_id,
				t_userfiles.f_gasmodel_id,
				t_userfiles.f_inputtor,
				t_userfiles.f_remanent_gas,
				t_userfiles.f_table_state,
				t_userfiles.version,
				t_userfiles.f_input_date,
				t_userfiles.f_card_password,
				t_userfiles.f_metertitles,
				t_userfiles.f_meter_classify,
				t_userfiles.f_initial_base,
				t_userfiles.f_meterid,
				t_userfiles.f_outlets,
				t_userfiles.f_filiale,
				t_userfiles.f_orgstr,
				t_userfiles.f_filialeids,
				t_userfiles.f_valve_state,
				t_userfiles.f_install_person,
				t_userfiles.f_install_date,
				t_userfiles.f_gas_date,
				t_userfiles.f_changetube_date,
				t_userfiles.f_changetube_person,
				t_userfiles.f_gas_person,
				t_userfiles.f_fire_state,
				t_userfiles.f_totalsplit_type,
				t_userfiles.f_share_ratio,
				t_userfiles.f_meter_id
			FROM
				t_userfiles
			INNER JOIN t_userinfo ON t_userinfo.f_userinfo_id = t_userfiles.f_userinfo_id
		) t
	LEFT OUTER JOIN t_gasbrand ON t_gasbrand.id = t.f_gasbrand_id
	LEFT OUTER JOIN t_gasmodel ON t_gasmodel.id = t.f_gasmodel_id
	LEFT OUTER JOIN (
	select * from t_stairprice where getdate()>=f_perform_date and getdate()<=f_end_date
	) s ON s.f_price_id = t.f_price_id
	{ entity.findDialect () == $SqlServer$ : $$,
	$
) $ }

==> sale-1.9.1.jar: revenue/sqls/view/V_user_table.sql <==
{ entity.findDialect () == $SqlServer$ : $$,
 $ (
	$ } SELECT
	  t.f_userinfo_code,  --真正显示的用户编号
		t.f_user_state,
		t.f_balance,
		t.f_cost_type,
		t.f_user_name,
		t.f_address,
		t.f_address_str,
		t.f_street,
		t.f_residential_area,
		t.f_unit,
		t.f_building,
		t.f_floor,
		t.f_room,
		t.f_credentials,
		t.f_idnumber,
		t.f_user_phone,
		t.userinfo_version,
		t.f_createfile_date,
		t.f_area,
		t.f_user_id,
		t.f_userinfo_id,
		t.f_position,
		t.f_meter_base,
		t.f_total_fee,
		t.f_meternumber,
		t.f_card_id,
		t.f_aroundmeter,
		t.f_times,
		t.f_balance_amount,
	  t.f_balance_gas,
		t.f_whether_hairpin,
		t.f_gasbrand_id,
		t.f_gasmodel_id,
		t.f_price_id,
		s.id f_stairprice_id,
		s.f_price_name,
		s.f_price_type,
		s.f_limit_cycle,
		s.f_limit_gas,
		t.f_inputtor,
		t.f_remanent_gas,
		t.f_table_state,
		t.version,
		t.f_input_date,
		t.f_card_password,
		t.f_metertitles,
		t.f_meter_classify,
		t.f_initial_base,
		t.f_meterid,
		t.f_open_id,
		t.f_operator,
		t.f_user_type,
		t.f_gasproperties,
		t.f_outlets,
		t.f_filiale,
		t.f_orgstr,
		t.f_filialeids,
		t.f_valve_state,
		t.f_install_person,
		t.f_install_date,
		t.f_gas_date,
		t.f_contract_id,
		t.f_taxpayer_id,
		t.f_address_phone,
		t.f_paper_name,
		t.f_paper_type,
		t.f_paper_account,
		t.f_changetube_date,
		t.f_changetube_person,
		t.f_gas_person,
		t.f_fire_state,
		t_gasbrand.id,
		t_gasbrand.f_meter_brand,
		t_gasbrand.f_manufacturers,
		t_gasbrand.f_meter_type,
		t_gasbrand.f_meter_limit,
		t_gasbrand.f_police_gas,
		t_gasbrand.f_topup_ceil,
		t_gasbrand.f_overdr_lines,
		t_gasbrand.f_alias,
		t_gasbrand.f_checkout_limit,
		t_gasbrand.f_isdecimal,
		t_gasbrand.f_collection_type,
		t_gasmodel.f_meter_style,
		t_gasmodel.f_size_card,
		t_gasmodel.f_type,
		t_gasmodel.f_rated_traffic,
		t_gasmodel.f_coding,
		t_gasmodel.f_pulse,
		t.f_comments,
		t.f_totalsplit_type,
		t.f_share_ratio,
		t.f_meter_id
	FROM
		(
			SELECT
			  t_userinfo.f_userinfo_code, --真正显示的用户编号
				t_userinfo.f_user_state,
				t_userinfo.f_balance,
				t_userinfo.f_cost_type,
				t_userinfo.f_user_name,
				t_userinfo.f_address,
				t_userinfo.f_address_str,
				t_userinfo.f_street,
				t_userinfo.f_residential_area,
				t_userinfo.f_unit,
				t_userinfo.f_building,
				t_userinfo.f_floor,
				t_userinfo.f_room,
				t_userinfo.f_credentials,
				t_userinfo.f_idnumber,
				t_userinfo.f_user_phone,
				t_userinfo.version AS userinfo_version,
				t_userinfo.f_createfile_date,
				t_userinfo.f_area,
        t_userinfo.f_open_id,
				t_userinfo.f_operator,
				t_userinfo.f_user_type,
				t_userinfo.f_gasproperties,
				t_userinfo.f_price_id,
				t_userinfo.f_contract_id,
				t_userinfo.f_taxpayer_id,
				t_userinfo.f_address_phone,
				t_userinfo.f_paper_name,
				t_userinfo.f_paper_type,
				t_userinfo.f_paper_account,
        t_userinfo.f_comments,
				t_userfiles.f_user_id,
			  t_userfiles.f_userinfo_id,
				t_userfiles.f_position,
				t_userfiles.f_meter_base,
				t_userfiles.f_total_fee,
				t_userfiles.f_meternumber,
				t_userfiles.f_card_id,
				t_userfiles.f_aroundmeter,
				t_userfiles.f_times,
				t_userfiles.f_balance_amount,
				t_userfiles.f_balance_gas,
				t_userfiles.f_whether_hairpin,
				t_userfiles.f_gasbrand_id,
				t_userfiles.f_gasmodel_id,
				t_userfiles.f_inputtor,
				t_userfiles.f_remanent_gas,
				t_userfiles.f_table_state,
				t_userfiles.version,
				t_userfiles.f_input_date,
				t_userfiles.f_card_password,
				t_userfiles.f_metertitles,
				t_userfiles.f_meter_classify,
				t_userfiles.f_initial_base,
				t_userfiles.f_meterid,
				t_userfiles.f_outlets,
				t_userfiles.f_filiale,
				t_userfiles.f_orgstr,
				t_userfiles.f_filialeids,
				t_userfiles.f_valve_state,
				t_userfiles.f_install_person,
				t_userfiles.f_install_date,
				t_userfiles.f_gas_date,
				t_userfiles.f_changetube_date,
				t_userfiles.f_changetube_person,
				t_userfiles.f_gas_person,
				t_userfiles.f_fire_state,
				t_userfiles.f_totalsplit_type,
				t_userfiles.f_share_ratio,
				t_userfiles.f_meter_id
			FROM
				t_userfiles
			INNER JOIN t_userinfo ON t_userinfo.f_userinfo_id = t_userfiles.f_userinfo_id
		) t
	LEFT OUTER JOIN t_gasbrand ON t_gasbrand.id = t.f_gasbrand_id
	LEFT OUTER JOIN t_gasmodel ON t_gasmodel.id = t.f_gasmodel_id
	LEFT OUTER JOIN (
	select * from t_stairprice where getdate()>=f_perform_date and getdate()<=f_end_date  and f_state = '有效'
	) s ON s.f_price_id = t.f_price_id
	where s.f_filialeids = t.f_filialeids
	{ entity.findDialect () == $SqlServer$ : $$,
	$
) $ }
